@@ -2,6 +2,8 @@
 # -*- coding:Utf-8 -*- 
 
 # Copyright (C) 2008 Pâris Quentin
+# Copyright (C) 2009 Łukasz Wojniłowicz
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -158,6 +160,10 @@ class Ok_frame(wx.Frame): #fenêtre principale
 		self.SendBash("Ok")
 		self.NextButton.Enable(False)
 
+	def release_download(self, return_code):
+		self.SendBash("MSG_VALUE="+return_code)
+                self.NextButton.Enable(False)
+
 	def release_checkboxes(self, event):
 		self.i = 0
 		self.send = []
@@ -278,10 +284,28 @@ class Ok_frame(wx.Frame): #fenêtre principale
 		chemin = urlparse.urlsplit(url)[2] 
 		nomFichier = chemin.split('/')[-1] 
 		local = localB + nomFichier 
-		urllib.urlretrieve(url, local, reporthook = self.onHook)
+		try:
+			urllib.urlretrieve(url, local, reporthook = self.onHook)
+		except IOError:			#server don't respond
+			self.release_download("1")
+			return
+
+		self.FileTest = open(local, "r")
+		self.FileTest.seek(0, 2)
+		self.ReturnCode="0"
+
+		if self.FileTest.tell() <= 2000:    #if file is small, test it
+			self.FileTest.seek(0)
+			for x in self.FileTest:
+				if "404" in x and "Not Found" in x or "Could not open the requested SVN filesystem" in x or "The requested URL could not be retrieved" in x:
+					os.remove(local)
+					self.ReturnCode="2"
+					break
+		self.FileTest.close()	
+
 		#print "Fini dans "+local
 		self.txtEstimation.Destroy()
-		self.release(self)
+		self.release_download(self.ReturnCode)
 
 	def agree(self, event):
 		if(self.Menu.IsChecked()):
