@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (C) 2008 Pâris Quentin
-
+#		2010
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -31,6 +31,7 @@ class getDescription(threading.Thread):
 	self.htmlContent = ""
 	self.htmlwait = "###WAIT###"
 	self.stars = 0
+	self.cat = 0
 	self.start()
 	self.miniature = Variables.playonlinux_env+"/etc/pol_min.png"
 	self.miniature_defaut = Variables.playonlinux_env+"/etc/pol_min.png"
@@ -79,9 +80,13 @@ class getDescription(threading.Thread):
 						self.htmlContent = handle.read()	
 					except :
 					   	self.htmlContent = "<i>"+_("No description")+"</i>"
+			
+					if(self.cat == 12):
+						self.htmlContent += "<br /><br /><font color=red><b>WARNING !</b><br />You are going to execute a beta script. <br />This functionality has been added to make script testing easier.<br />It might not work as expected.</font>"
+
 					# Stars
 					try :
-						url = 'http://mulx.playonlinux.com/polistats/stars.php?n='+self.getDescription.replace(" ","%20")
+						url = 'http://repository.playonlinux.com/V3_data/repository/stars.php?n='+self.getDescription.replace(" ","%20")
 						req = urllib2.Request(url)
 						handle = urllib2.urlopen(req)
 						self.stars = handle.read()	
@@ -94,31 +99,30 @@ class getDescription(threading.Thread):
 
 class MainWindow(wx.Frame):
   def __init__(self,parent,id,title):
-    wx.Frame.__init__(self, parent, -1, title, size = (792, 573), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
+    wx.Frame.__init__(self, parent, -1, title, size = (792, 593), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
     self.panelFenp = wx.Panel(self, -1)
     self.live = 0
     self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
     self.images_cat = wx.ImageList(22, 22)
     self.imagesapps = wx.ImageList(22, 22)
-    self.list_cat = wx.TreeCtrl(self.panelFenp, 105, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(200, 343), pos=(10,10))
-    self.image = wx.StaticBitmap(self.panelFenp, -1, wx.Bitmap(Variables.playonlinux_env+"/etc/pol_min.png"), (10,363), wx.DefaultSize)
+    self.list_cat = wx.TreeCtrl(self.panelFenp, 105, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(200, 363), pos=(10,10))
+    self.image = wx.StaticBitmap(self.panelFenp, -1, wx.Bitmap(Variables.playonlinux_env+"/etc/pol_min.png"), (10,383), wx.DefaultSize)
     self.list_cat.SetSpacing(0);
     self.list_cat.SetImageList(self.images_cat)
     self.AddCats()
     self.searchbox = wx.TextCtrl(self.panelFenp, 110, size=(364,25), pos=(319,9))
     self.searchcaption = wx.StaticText(self.panelFenp, -1, _("Search :"), (220,15), wx.DefaultSize)
     self.lasthtml_content = ""
-    self.list_apps = wx.TreeCtrl(self.panelFenp, 106, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(562, 251), pos=(220,40))
+    self.list_apps = wx.TreeCtrl(self.panelFenp, 106, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(562, 261), pos=(220,40))
     self.list_apps.SetImageList(self.imagesapps)
     self.list_apps.SetSpacing(0);
     self.stars = 0
-    #self.content =  wx.TextCtrl(self.panelFenp, 107, pos=(220,301), size=(562,212), style = wx.TE_MULTILINE | wx.TE_RICH2 | wx.CB_READONLY | wx.RAISED_BORDER)
-    self.content = wx.html.HtmlWindow(self.panelFenp, 107, style=wx.RAISED_BORDER, pos=(220,301), size=(562,212))
-    self.button = wx.Button(self.panelFenp, wx.ID_CLOSE, pos=(576, 525), size=(100,35))
-    self.install_button = wx.Button(self.panelFenp, wx.ID_APPLY, pos=(683, 525), size=(100,35))
-    self.update_button = wx.Button(self.panelFenp, wx.ID_REFRESH, pos=(470, 525), size=(100,35))
+    self.content = wx.html.HtmlWindow(self.panelFenp, 107, style=wx.RAISED_BORDER, pos=(220,311), size=(562,222))
+    self.button = wx.Button(self.panelFenp, wx.ID_CLOSE, pos=(576, 545), size=(100,35))
+    self.install_button = wx.Button(self.panelFenp, wx.ID_APPLY, pos=(683, 545), size=(100,35))
+    self.update_button = wx.Button(self.panelFenp, wx.ID_REFRESH, pos=(470, 545), size=(100,35))
     self.install_button.Enable(False)
-    self.new_panel = wx.Panel(self.panelFenp, -1, pos=(220,301), style=wx.RAISED_BORDER, size=(562,212))
+    self.new_panel = wx.Panel(self.panelFenp, -1, pos=(220,311), style=wx.RAISED_BORDER, size=(562,222))
     self.new_panel.SetBackgroundColour((255,255,255))
     self.animation = wx.animate.GIFAnimationCtrl(self.new_panel, -1, Variables.playonlinux_env+"/etc/24-0.gif", (271,86))
     self.animation.Play()
@@ -129,7 +133,7 @@ class MainWindow(wx.Frame):
     self.timer.Start(200)
 
     #self.ManualInstall = wx.CheckBox(self.panelFenp, 111, label=_("Install a .pol package or an unsupported application"), pos=(10,530))
-    self.ManualInstall = wx.HyperlinkCtrl(self.panelFenp, 111, _("Install a .pol package or an unsupported application"), "", pos=(10,535))
+    self.ManualInstall = wx.HyperlinkCtrl(self.panelFenp, 111, _("Install a .pol package or an unsupported application"), "", pos=(10,565))
     self.ManualInstall.SetNormalColour(wx.Colour(0,0,0))
    # self.AddApps()
 
@@ -162,6 +166,9 @@ class MainWindow(wx.Frame):
 		self.show_stars(description.stars)
 		self.stars = description.stars
 
+	if(self.list_cat.GetItemImage(self.list_cat.GetSelection()) != description.cat):
+		description.cat = self.list_cat.GetItemImage(self.list_cat.GetSelection())
+
 
   def closeapp(self, event):
 	description.thread_running = False	
@@ -218,8 +225,9 @@ class MainWindow(wx.Frame):
 		print "ExecLiveInstall"
 	else:
 		print self.list_apps.GetItemText(self.list_apps.GetSelection())
-	self.Close()   
-	sys.exit(0) 
+	self.closeapp(self)	
+	#self.Close()   
+	#sys.exit(0) 
 
   def search(self, event):
 	self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/search",'r',"utf-8")
@@ -275,6 +283,11 @@ class MainWindow(wx.Frame):
     self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/applications-multimedia.png"))
     self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/applications-office.png"))
     self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/applications-other.png"))
+    self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/emblem-favorite.png"))
+    self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/face-smile.png"))
+    self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/view-refresh.png"))
+    self.images_cat.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/applications-testing.png"))
+
 #    self.cats.sort()
     self.list_cat.DeleteAllItems()
     self.root = self.list_cat.AddRoot("")
@@ -282,6 +295,12 @@ class MainWindow(wx.Frame):
     for cat in self.cats:
 	self.list_cat.AppendItem(self.root, cat, self.i)
 	self.i = self.i+1
+    
+    self.list_cat.AppendItem(self.root, "",-1)
+    self.list_cat.AppendItem(self.root, _("Highest rated"), self.i)
+    self.list_cat.AppendItem(self.root, _("Most downloaded"), self.i+1)
+    self.list_cat.AppendItem(self.root, _("Patches"), self.i+2)
+    self.list_cat.AppendItem(self.root, _("Testing"), self.i+3)
 
   def WriteApps(self, array):
 	self.imagesapps.RemoveAll()
@@ -289,7 +308,7 @@ class MainWindow(wx.Frame):
 	self.DelApps()
 	self.root_apps = self.list_apps.AddRoot("")
 	self.i = 0
-	array.sort()
+	#array.sort()
 	for app in array:
 		self.icon_look_for = Variables.playonlinux_rep+"/configurations/icones/"+app
 		if(os.path.exists(self.icon_look_for)):
@@ -304,7 +323,7 @@ class MainWindow(wx.Frame):
 
   def SetImg(self, image):
 	self.image.Destroy()
-	self.image = wx.StaticBitmap(self.panelFenp, -1, wx.Bitmap(image), (10,363), wx.DefaultSize)
+	self.image = wx.StaticBitmap(self.panelFenp, -1, wx.Bitmap(image), (10,383), wx.DefaultSize)
 
   def ResetImg(self):
 	self.SetImg(Variables.playonlinux_env+"/etc/pol_min.png")
@@ -313,32 +332,41 @@ class MainWindow(wx.Frame):
 	self.searchbox.SetValue("")
 	#self.cat_selected=self.list_cat.GetItemText(self.list_cat.GetSelection()).encode('utf-8')
 	self.cat_selected = self.list_cat.GetItemImage(self.list_cat.GetSelection())
-	#print self.cat_selected
-	if(self.cat_selected == 8):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/0",'r',"utf-8")
-	if(self.cat_selected == 3):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/1",'r',"utf-8")
-	if(self.cat_selected == 0):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/2",'r',"utf-8")
-	if(self.cat_selected == 7):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/3",'r',"utf-8")
-	if(self.cat_selected == 5):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/4",'r',"utf-8")
-	if(self.cat_selected == 6):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/5",'r',"utf-8")
-	if(self.cat_selected == 4):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/6",'r',"utf-8")
-	if(self.cat_selected == 1):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/7",'r',"utf-8")
-	if(self.cat_selected == 2):
-		self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/8",'r',"utf-8")
-
-	self.apps = self.apps.readlines()
-	self.j = 0
-	while(self.j < len(self.apps)):
-		self.apps[self.j] = self.apps[self.j].replace("\n","")
-		self.j += 1
-	self.WriteApps(self.apps)
+	if(self.cat_selected == -1):
+		self.list_cat.UnselectAll()
+	else:
+		if(self.cat_selected == 8):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/0",'r',"utf-8")
+		if(self.cat_selected == 3):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/1",'r',"utf-8")
+		if(self.cat_selected == 0):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/2",'r',"utf-8")
+		if(self.cat_selected == 7):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/3",'r',"utf-8")
+		if(self.cat_selected == 5):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/4",'r',"utf-8")
+		if(self.cat_selected == 6):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/5",'r',"utf-8")
+		if(self.cat_selected == 4):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/6",'r',"utf-8")
+		if(self.cat_selected == 1):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/7",'r',"utf-8")
+		if(self.cat_selected == 2):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/8",'r',"utf-8")
+		if(self.cat_selected == 11):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/9",'r',"utf-8")
+		if(self.cat_selected == 12):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/10",'r',"utf-8")
+		if(self.cat_selected == 10):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/download",'r',"utf-8")
+		if(self.cat_selected == 9):
+			self.apps = codecs.open(Variables.playonlinux_rep+"/configurations/listes/rate",'r',"utf-8")
+		self.apps = self.apps.readlines()
+		self.j = 0
+		while(self.j < len(self.apps)):
+			self.apps[self.j] = self.apps[self.j].replace("\n","")
+			self.j += 1
+		self.WriteApps(self.apps)
 
 class PlayOnLinuxApp(wx.App):
    def OnInit(self):
